<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

### Table of Contents

-   [getConfig](#getconfig)
-   [add](#add)
-   [get](#get)
-   [getAll](#getall)
-   [remove](#remove)

This module allows to create shortcuts for functions and commands (via command id)

You can access the module in this way

```js
const keymaps = editor.Keymaps;
```

## getConfig

Get module configurations

Returns **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** Configuration object

## add

Add new keymap

**Parameters**

-   `id` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** Keymap id
-   `keys` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** Keymap keys, eg. `ctrl+a`, `⌘+z, ctrl+z`
-   `handler` **([Function](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Statements/function) \| [string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String))** Keymap handler, might be a function

**Examples**

```javascript
// 'ns' is just a custom namespace
keymaps.add('ns:my-keymap', '⌘+j, ⌘+u, ctrl+j, alt+u', editor => {
 console.log('do stuff');
});
// or
keymaps.add('ns:my-keymap', '⌘+s, ctrl+s', 'some-gjs-command');

// listen to events
editor.on('keymap:emit', (id, shortcut, e) => {
 // ...
})
```

Returns **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** Added keymap
 or just a command id as a string

## get

Get the keymap by id

**Parameters**

-   `id` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** Keymap id

**Examples**

```javascript
keymaps.get('ns:my-keymap');
// -> {keys, handler};
```

Returns **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** Keymap object

## getAll

Get all keymaps

**Examples**

```javascript
keymaps.getAll();
// -> {id1: {}, id2: {}};
```

Returns **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)**

## remove

Remove the keymap by id

**Parameters**

-   `id` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** Keymap id

**Examples**

```javascript
keymaps.remove('ns:my-keymap');
// -> {keys, handler};
```

Returns **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** Removed keymap
